# splotch
**Simple PLOTs, Contours and Histograms** is a small package with wrapper functions designed to simplify plotting calls from matplotlib.

The package is available in for installation using `>pip install splotch`, though you may get the lastest stable version using `>pip install git+https://github.com/MBravoS/splotch.git@master`, or the latest development version using `>pip install git+https://github.com/MBravoS/splotch.git@devel`.

The documentation is [splotch's readthedocs page](https://splotch.readthedocs.io/en/latest/). 

*Current version*: 0.4.0.0

*Planned releases*:
* Addition of error raising for unclear errors when breaking plots (0.4.1.0).
* Addition of error/dispersion band plots (0.4.2.0).
* Addition of legend customisation function (0.4.3.0).
